use strict;
use warnings;
package MooseX::Role::Parameterised;
# vim: set ts=8 sts=4 sw=4 tw=115 et :
# ABSTRACT: Moose roles with composition parameters

our $VERSION = '1.11';

__END__

=pod

=encoding UTF-8

=head1 NAME

MooseX::Role::Parameterised - Moose roles with composition parameters

=head1 VERSION

version 1.11

=head1 SYNOPSIS

See L<MooseX::Role::Parameterized>; this module is just a stub to help the
civilised Perl users find this distribution with search engines. :)

=head1 SUPPORT

Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Role-Parameterized>
(or L<bug-MooseX-Role-Parameterized@rt.cpan.org|mailto:bug-MooseX-Role-Parameterized@rt.cpan.org>).

There is also a mailing list available for users of this distribution, at
L<http://lists.perl.org/list/moose.html>.

There is also an irc channel available for users of this distribution, at
L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.

=head1 AUTHOR

Shawn M Moore <code@sartak.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2008 by Shawn M Moore.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
